#
# spec file for package perl-Apache-DBI
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Apache-DBI
Name:           perl-Apache-DBI
Version:        1.120.0
Release:        1.1
# 1.12 -> normalize -> 1.120.0
%define cpan_version 1.12
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Initiate a persistent database connection
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PH/PHRED/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
Patch0:         Apache-DBI-1.11-path.patch
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DBI) >= 1
BuildRequires:  perl(Digest::SHA1) >= 2.10
Requires:       perl(DBI) >= 1
Requires:       perl(Digest::SHA1) >= 2.10
Provides:       perl(Apache::AuthDBI) = %{version}
Provides:       perl(Apache::DBI) = %{version}
Provides:       perl(Apache::DBI::db)
%undefine       __perllib_provides
%{perl_requires}

%description
This module initiates a persistent database connection.

The database access uses Perl's DBI. For supported DBI drivers see:

 http://dbi.perl.org/

When loading the DBI module (do not confuse this with the Apache::DBI
module) it checks if the environment variable 'MOD_PERL' has been set and
if the module Apache::DBI has been loaded. In this case every connect
request will be forwarded to the Apache::DBI module. This checks if a
database handle from a previous connect request is already stored and if
this handle is still valid using the ping method. If these two conditions
are fulfilled it just returns the database handle. The parameters defining
the connection have to be exactly the same, including the connect
attributes! If there is no appropriate database handle or if the ping
method fails, a new connection is established and the handle is stored for
later re-use. There is no need to remove the disconnect statements from
your code. They won't do anything because the Apache::DBI module overloads
the disconnect method.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -N

%patch -P0

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README TODO traces.txt

%changelog
* Tue Jun  3 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Mon Mar  4 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.12
  see /usr/share/doc/packages/perl-Apache-DBI/Changes
  1.12 June 12, 2013
  - Fix detection of server startup in mod_perl 2, to avoid caching
    connections in the parent process. Perrin Harkins
    <perrin@elem.com>
* Thu Oct 20 2011 tabraham@novell.com
- update to 1.11
  * RT 69087, perl 5.14 'Using qw(...) as parentheses' fix
* Mon Feb  7 2011 vcizek@novell.com
- update to 1.10
  - Add Apache2::RequestUtil for mp2 instances.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Nov 18 2010 anicka@suse.cz
- update to 1.09
  * Fix pod errors
  * Adds PerlChildExitHandler to disconnect existing connections
* Tue Feb 23 2010 anicka@suse.cz
- update to 1.08
  * Fix bug to allow DBI in startup.pl etc again
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Thu Jun 19 2008 anicka@suse.cz
- update to 1.07
  * http://rt.cpan.org/Public/Bug/Display.html?id=31003
  * http://rt.cpan.org/Public/Bug/Display.html?id=29209
    PerlCleanupHandler doesn't get called with MP2
  * http://rt.cpan.org/Public/Bug/Display.html?id=28824
    Documentation Additions
* Fri Mar 30 2007 anicka@suse.cz
- update to 1.06
  * MP2/AuthDBI: Fixed Apache::AuthDBI::debug() to
    actually work.
  * Bump minium required perl version to 5.6.1 to match DBI
* Wed Dec 13 2006 anicka@suse.cz
- update to 1.05
  * MP2/AuthDBI: Add missing Apache2::Access
  * MP1: Undefined subroutine &Apache2::Const::OK called at ....
* Wed Sep 13 2006 anicka@suse.cz
- update to 1.03
  * three minor bugfixes
* Wed Jul 12 2006 anicka@suse.cz
- update to 1.01
  * As DBI has supported only perl 5.6.0 since 2003
    v1.38 Apache::DBI now requires perl 5.6.0 as well.
  * Fix a plethora of uninitialized variable warnings,
    general code cleanup, don't import unneeded symbols
    from Carp, Digest::SHA1, and Digest::MD5
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 10 2006 anicka@suse.cz
- update to 0.9901
- fix #neededforbuild
* Mon Aug  1 2005 pth@suse.de
- Fix file list
* Tue Jun 15 2004 ro@suse.de
- updated requires
* Wed May  5 2004 mjancar@suse.cz
- update neededforbuild
* Thu Feb 26 2004 mjancar@suse.cz
- update to 0.94
* Thu Oct 30 2003 mjancar@suse.cz
- update to 0.92
* Wed Sep 17 2003 kukuk@suse.de
- Add provides/obsoletes for package rename
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Mon Jun 23 2003 mjancar@suse.cz
- update to 0.91
- rename to perl-Apache-DBI
- fix filelist
* Tue May 20 2003 mjancar@suse.cz
- remove unpackaged files
* Mon Jul 22 2002 prehak@suse.cz
- doesn't require any specific apache version,
  simply require apache [#16775]
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Mon Nov  5 2001 poeml@suse.de
- use apache-devel-packages macro in #neededforbuild
  (expat.rpm is needed by apxs)
* Sun Aug 12 2001 kukuk@suse.de
- Fix path to perl interpreter
* Wed Mar 28 2001 rolf@suse.de
- update to 0.88
* Fri Feb 23 2001 ro@suse.de
- changed neededforbuild <apache> to <apache apache-devel>
* Thu Nov 16 2000 rolf@suse.de
- extracted from perlmod package
